Index: src/mips/lithium-codegen-mips.cc |
diff --git a/src/mips/lithium-codegen-mips.cc b/src/mips/lithium-codegen-mips.cc |
index 900ccd5f9e88f44a5a739fdf0e1dfd86e739a462..970a1bfc25c197ad78e95442408aa05a59cebd15 100644 |
--- a/src/mips/lithium-codegen-mips.cc |
+++ b/src/mips/lithium-codegen-mips.cc |
@@ -207,7 +207,7 @@ bool LCodeGen::GeneratePrologue() { |
__ CallStub(&stub); |
} else { |
__ push(a1); |
- __ CallRuntime(Runtime::kNewFunctionContext, 1); |
+ __ CallRuntime(Runtime::kHiddenNewFunctionContext, 1); |
} |
RecordSafepoint(Safepoint::kNoLazyDeopt); |
// Context is returned in both v0. It replaces the context passed to us. |
@@ -3499,7 +3499,7 @@ void LCodeGen::DoDeclareGlobals(LDeclareGlobals* instr) { |
__ li(scratch1(), Operand(Smi::FromInt(instr->hydrogen()->flags()))); |
// The context is the first argument. |
__ Push(cp, scratch0(), scratch1()); |
- CallRuntime(Runtime::kDeclareGlobals, 3, instr); |
+ CallRuntime(Runtime::kHiddenDeclareGlobals, 3, instr); |
} |
@@ -3588,7 +3588,7 @@ void LCodeGen::DoDeferredMathAbsTaggedHeapNumber(LMathAbs* instr) { |
// Slow case: Call the runtime system to do the number allocation. |
__ bind(&slow); |
- CallRuntimeFromDeferred(Runtime::kAllocateHeapNumber, 0, instr, |
+ CallRuntimeFromDeferred(Runtime::kHiddenAllocateHeapNumber, 0, instr, |
instr->context()); |
// Set the pointer to the new heap number in tmp. |
if (!tmp1.is(v0)) |
@@ -4672,11 +4672,11 @@ void LCodeGen::DoDeferredNumberTagIU(LInstruction* instr, |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
// They only call Runtime::kAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
__ lw(cp, MemOperand(fp, StandardFrameConstants::kContextOffset)); |
- __ CallRuntimeSaveDoubles(Runtime::kAllocateHeapNumber); |
+ __ CallRuntimeSaveDoubles(Runtime::kHiddenAllocateHeapNumber); |
RecordSafepointWithRegisters( |
instr->pointer_map(), 0, Safepoint::kNoLazyDeopt); |
__ Subu(v0, v0, kHeapObjectTag); |
@@ -4737,11 +4737,11 @@ void LCodeGen::DoDeferredNumberTagD(LNumberTagD* instr) { |
PushSafepointRegistersScope scope(this, Safepoint::kWithRegisters); |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
// They only call Runtime::kAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
__ lw(cp, MemOperand(fp, StandardFrameConstants::kContextOffset)); |
- __ CallRuntimeSaveDoubles(Runtime::kAllocateHeapNumber); |
+ __ CallRuntimeSaveDoubles(Runtime::kHiddenAllocateHeapNumber); |
RecordSafepointWithRegisters( |
instr->pointer_map(), 0, Safepoint::kNoLazyDeopt); |
__ Subu(v0, v0, kHeapObjectTag); |
@@ -5351,7 +5351,7 @@ void LCodeGen::DoDeferredAllocate(LAllocate* instr) { |
__ Push(Smi::FromInt(flags)); |
CallRuntimeFromDeferred( |
- Runtime::kAllocateInTargetSpace, 2, instr, instr->context()); |
+ Runtime::kHiddenAllocateInTargetSpace, 2, instr, instr->context()); |
__ StoreToSafepointRegisterSlot(v0, result); |
} |
@@ -5385,7 +5385,7 @@ void LCodeGen::DoRegExpLiteral(LRegExpLiteral* instr) { |
__ li(t1, Operand(instr->hydrogen()->pattern())); |
__ li(t0, Operand(instr->hydrogen()->flags())); |
__ Push(t3, t2, t1, t0); |
- CallRuntime(Runtime::kMaterializeRegExpLiteral, 4, instr); |
+ CallRuntime(Runtime::kHiddenMaterializeRegExpLiteral, 4, instr); |
__ mov(a1, v0); |
__ bind(&materialized); |
@@ -5398,7 +5398,7 @@ void LCodeGen::DoRegExpLiteral(LRegExpLiteral* instr) { |
__ bind(&runtime_allocate); |
__ li(a0, Operand(Smi::FromInt(size))); |
__ Push(a1, a0); |
- CallRuntime(Runtime::kAllocateInNewSpace, 1, instr); |
+ CallRuntime(Runtime::kHiddenAllocateInNewSpace, 1, instr); |
__ pop(a1); |
__ bind(&allocated); |
@@ -5432,7 +5432,7 @@ void LCodeGen::DoFunctionLiteral(LFunctionLiteral* instr) { |
__ li(a1, Operand(pretenure ? factory()->true_value() |
: factory()->false_value())); |
__ Push(cp, a2, a1); |
- CallRuntime(Runtime::kNewClosure, 3, instr); |
+ CallRuntime(Runtime::kHiddenNewClosure, 3, instr); |
} |
} |
@@ -5656,7 +5656,7 @@ void LCodeGen::DoDummyUse(LDummyUse* instr) { |
void LCodeGen::DoDeferredStackCheck(LStackCheck* instr) { |
PushSafepointRegistersScope scope(this, Safepoint::kWithRegisters); |
LoadContextFromDeferred(instr->context()); |
- __ CallRuntimeSaveDoubles(Runtime::kStackGuard); |
+ __ CallRuntimeSaveDoubles(Runtime::kHiddenStackGuard); |
RecordSafepointWithLazyDeopt( |
instr, RECORD_SAFEPOINT_WITH_REGISTERS_AND_NO_ARGUMENTS); |
ASSERT(instr->HasEnvironment()); |
@@ -4672,11 +4672,11 @@ void LCodeGen::DoDeferredNumberTagIU(LInstruction* instr, |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
- // They only call Runtime::kAllocateHeapNumber. |
+ // They only call Runtime::kHiddenAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
@@ -4737,11 +4737,11 @@ void LCodeGen::DoDeferredNumberTagD(LNumberTagD* instr) { |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
- // They only call Runtime::kAllocateHeapNumber. |
+ // They only call Runtime::kHiddenAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |